# gelee

Gelee - a finer confiture.

Configuration linter for typical formats.

Documentation:

* [Installation](install.md)
* [Use](use.md)
* [Command Line API](api.md)
* [Changes](changes.md)

## Status

Experimental.
